LavueController Tango Class Properties

LavueController Properties :
There is no class properties

Device Properties
Name | Description | Type | Default Value
DynamicROIs | create dynamically Attributes for ROIs aliases with their bounds | boolean | True
DynamicROIsValues | create dynamically Attributes for ROIs aliases with their sums | boolean | True
ROIAttributesNames | fixed ROI attributes names, They should ends with ROI, Sum or Sums | String[] | none